@@ -8,7 +8,7 @@
 # Next two lines simply add the path of the gem to the load path.
 # This is not needed when being loaded as a gem; but when doing
 # plugin development, you may need it.  Either way, it's harmless.
-libdir = File.dirname(__FILE__)
+libdir = __dir__
 $LOAD_PATH.unshift(libdir) unless $LOAD_PATH.include?(libdir)
 
 # It's traditional to keep your gem version in a separate file, so CI can find it easier.
