@@ -1,12 +1,10 @@
-# encoding: utf-8
-
 require "train/plugins"
 require "ms_rest_azure"
 require "azure_mgmt_resources"
 require "azure_graph_rbac"
 require "azure_mgmt_key_vault"
-require "socket"
-require "timeout"
+require "socket" unless defined?(Socket)
+require "timeout" unless defined?(Timeout)
 require "train/transports/helpers/azure/file_credentials"
 require "train/transports/clients/azure/graph_rbac"
 require "train/transports/clients/azure/vault"
@@ -33,6 +31,7 @@ module Train::Transports
       DEFAULT_FILE = ::File.join(Dir.home, ".azure", "credentials")
 
       def initialize(options)
+        warn("Azure Connection with Train will be deprecated from Train 4")
         @apis = {}
 
         # Override for any cli options
@@ -165,12 +164,10 @@ module Train::Transports
 
       def port_open?(port, seconds = 3)
         Timeout.timeout(seconds) do
-          begin
-            TCPSocket.new("localhost", port).close
-            true
-          rescue SystemCallError
-            false
-          end
+          TCPSocket.new("localhost", port).close
+          true
+        rescue SystemCallError
+          false
         end
       rescue Timeout::Error
         false
