@@ -1,12 +1,10 @@
-# encoding: utf-8
-
 require "train/plugins"
 require "google/apis"
-require "google/apis/cloudresourcemanager_v1"
-require "google/apis/compute_v1"
-require "google/apis/storage_v1"
-require "google/apis/iam_v1"
-require "google/apis/admin_directory_v1"
+require "google-apis-cloudresourcemanager_v1"
+require "google-apis-compute_v1"
+require "google-apis-storage_v1"
+require "google-apis-iam_v1"
+require "google-apis-admin_directory_v1"
 require "googleauth"
 
 module Train::Transports
@@ -40,8 +38,9 @@ module Train::Transports
         super(options)
 
         # additional GCP platform metadata
-        release = Gem.loaded_specs["google-api-client"].version
-        @platform_details = { release: "google-api-client-v#{release}" }
+        # The google-apis-core dependency is the common for all gcp service related gems.
+        release = Gem.loaded_specs["google-apis-core"].version
+        @platform_details = { release: "google-apis-core-v#{release}" }
 
         # Initialize the client object cache
         @cache_enabled[:api_call] = true
@@ -107,9 +106,10 @@ module Train::Transports
       def unique_identifier
         unique_id = "default"
         # use auth client_id for users (issuer is nil)
-        unique_id = gcp_iam_client.request_options.authorization.client_id unless gcp_iam_client.request_options.authorization.client_id.nil?
+        authorization = gcp_iam_client.request_options.authorization
+        unique_id = authorization.client_id if authorization.respond_to?(:client_id) && !authorization.client_id.nil?
         # for service account credentials (client_id is nil)
-        unique_id = gcp_iam_client.request_options.authorization.issuer unless gcp_iam_client.request_options.authorization.issuer.nil?
+        unique_id = authorization.issuer if authorization.respond_to?(:issuer) && !authorization.issuer.nil?
         unique_id
       end
     end
