@@ -1,4 +1,4 @@
-lib = File.expand_path("../../lib", __FILE__)
+lib = File.expand_path("../lib", __dir__)
 $LOAD_PATH.unshift(lib) unless $LOAD_PATH.include?(lib)
 
 require "train-test-fixture/transport"
