@@ -1,8 +1,3 @@
-# encoding: utf-8
-
-require "coveralls"
-Coveralls.wear!
-
 require "minitest/autorun"
 require "minitest/spec"
 
